@@ -40,7 +40,7 @@ use warnings::unused;
 
 our @EXPORT = qw( descend ); # our @EXPORT = qw( );
 
-$VERSION = '0.49.00'; # our $VERSION = '';
+$VERSION = '0.52.00'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
@@ -55,11 +55,8 @@ sub descend
 	my $countcase = $dat{countcase}; #say "dump(\$countcase): " . dump($countcase); # IT WILL BE SHADOWED. CUT ZZZ
 	my $countblock = $dat{countblock}; #say "dump(\$countblock): " . dump($countblock); # IT WILL BE SHADOWED. CUT ZZZ		
 	my %dirfiles = %{ $dat{dirfiles} }; #say "dump(\%dirfiles): " . dump(%dirfiles); 
-	#my $repfile = $dat{repfile}; 
 		
 	$configfile = $main::configfile; #say "dump(\$configfile): " . dump($configfile);
-	@sweeps = @main::sweeps; #say "dump(\@sweeps): " . dump(@sweeps);
-	@sourcesweeps = @main::sourcesweeps; #say "dump(\@sourcesweeps): " . dump(@sourcesweeps);
 	@varinumbers = @main::varinumbers; #say "dump(\@varinumbers): " . dump(@varinumbers);
 	@mediumiters = @main::mediumiters;
 	@rootnames = @main::rootnames; #say "dump(\@rootnames): " . dump(@rootnames);
@@ -79,7 +76,6 @@ sub descend
 	#open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
 	open( TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!";  
 	$tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
-	say "\nNow in Sim::OPT::Descend.\n";
 	say $tee "\n#Now in Sim::OPT::Descend.\n";
 	
 	#say TOFILE "dump(\$repfile): " . dump($repfile); 
@@ -111,7 +107,7 @@ sub descend
 	my @retcases = @{ $dirfiles{retcases} }; #say TOFILE "dumpINDESCEND2(\@retcases): " . dump(@retcases);
 	my @retstruct = @{ $dirfiles{retstruct} }; #say TOFILE"dump(\@retstruct): " . dump(@retstruct);
 	my @repcases = @{ $dirfiles{repcases} };  #say TOFILE"dumpINDESCEND(\@repcases): " . dump(@repcases);
-	my @repstruct = @{ $dirfiles{repstruct} }; #say TOFILE"dumpINDESCEND(\@repstruct): " . dump(@repstruct);
+	my @repstruct = @{ $dirfiles{repstruct} }; say $tee "dumpINDESCEND(\@repstruct): " . dump(@repstruct);
 	my @mergecases = @{ $dirfiles{mergecases} }; #say TOFILE"dumpINDESCEND(\@mergecases): " . dump(@mergecases);
 	my @mergestruct = @{ $dirfiles{mergestruct} }; #say TOFILE"dumpINDESCEND(\@mergestruct): " . dump(@mergestruct);
 	my @descendcases = @{ $dirfiles{descendcases} }; #say TOFILE"dumpINDESCEND(\@descendcases): " . dump(@descendcases);
@@ -139,22 +135,32 @@ sub descend
 
 	#my $getpars = shift;
 	#eval( $getpars );
-	my $repfile = $repstruct[$countcase][$countblock][0]; #say TOFILE "OBTAINED \$repfile : " . dump( $repfile );
+	my $repfile = $repstruct[$countcase][$countblock][0]; say $tee "OBTAINED \$repfile : " . dump( $repfile );
+	if ( not ( defined( $repfile ) ) )
+	{
+		$repfile = $dirfiles{repfilebackup}; 
+	}
+	say $tee "OBTAINED BACKUP \$repfile : " . dump( $repfile );
 	
 	my $instance = $instances[0]; # THIS WOULD HAVE TO BE A LOOP HERE TO MIX ALL THE MERGECASES!!! ### ZZZ
 	
 	my %d = %{$instance};
 	my $countcase = $d{countcase}; #say TOFILE "dump(\$countcase): " . dump($countcase);
 	my $countblock = $d{countblock}; #say TOFILE "dump(\$countblock): " . dump($countblock);
-	my @miditers = @{ $d{miditers} }; #say TOFILE "BEGINDESCENDdump(\@miditers): " . dump(@miditers);
-	my @winneritems = @{ $d{winneritems} }; #say TOFILE "dumpIN( \@winneritems) " . dump(@winneritems);
+	my @miditers = @{ $d{miditers} }; say $tee "BEGIN DESCENT \@miditers : " . dump(@miditers);
+	my @winneritems = @{ $d{winneritems} }; say $tee " \@winneritems " . dump(@winneritems);
 	my $countvar = $d{countvar}; #say TOFILE "dump(\$countvar): " . dump($countvar);
 	my $countstep = $d{countstep}; #say TOFILE "dump(\$countstep): " . dump($countstep);						
 	my $to = $d{to}; #say TOFILE "dump(\$to): " . dump($to);
 	my $origin = $d{origin}; #say TOFILE "dump(\$origin): " . dump($origin);
 	my @uplift = @{ $d{uplift} }; #say TOFILE "dump(\@uplift): " . dump(@uplift);
+	my @backvalues = @{ $d{backvalues} }; say $tee "IN DESCENT \@backvalues " . dump(@backvalues);
+	my @sweeps = @{ $d{sweeps} }; say $tee "dump(\@sweeps): " . dump(@sweeps);
+	my @sourcesweeps = @{ $d{sourcesweeps} }; say $tee "dump(\@sourcesweeps): " . dump(@sourcesweeps);
 	#eval($getparshere);
 	
+	my $counthold = 0;
+	
 	my $skip = $vals{$countvar}{skip}; #say TOFILE "dumpinreport(\$skip): " . dump($skip);
 	
 	my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOFILE "dump(\$rootname): " . dump($rootname);
@@ -186,7 +192,7 @@ sub descend
 	{ 	# IT CLEANS THE MIXED FILE AND SELECTS SOME COLUMNS, THEN COPIES THEM IN ANOTHER FILE
 		my ( $repfile, $cleanmixed, $selectmixed ) = @_;
 		say $tee "Cleaning results for case $countcaseplus, block $contblocksplus.";
-		open( MIXFILE, $repfile ) or die( "$!" ); say TOFILE "dump(\$repfile IN SUB cleanselect): " . dump($repfile); 
+		open( MIXFILE, $repfile ) or die( "$!" ); say $tee "dump(\$repfile IN SUB cleanselect): " . dump($repfile); 
 		my @lines = <MIXFILE>; #say TOFILE "dump(MIXFILE \@lines): " . dump(@lines); 
 		close MIXFILE;
 		open( CLEANMIXED, ">$cleanmixed" ) or die( "$!" );
@@ -536,7 +542,7 @@ sub descend
 			{
 				if ($countelm > 0)
 				{
-					if ( $val ==  $winnerval)
+					if ( $val ==  $winnerval )
 					{
 						say MESSAGE "Attention. At case $countcaseplus, block $contblocksplus. There is a tie between optimal cases. Besides case $winnerline, producing a compound objective function of $winnerval, there is the case $case producing the same objective function value. Case $winnerline has been used for the search procedures which follow.\n";
 					}
@@ -545,16 +551,58 @@ sub descend
 			$countelm++;
 		}
 		close (MESSAGE);
+	say $tee "BEFORE PUSHING --->\@backvalues " . dump( @backvalues );
+		my ( $copy, $newtarget );
+		my ( @taken );
+		my ( %newcarrier );	
+		push( @backvalues, [ $winnerline, $winnerval ] );  say $tee "OBTAINED--->\@backvalues " . dump( @backvalues );
+		say $tee "\$sourcesweeps[ \$countcase ][ \$countblock ][0] " . dump( $sourcesweeps[ $countcase ][ $countblock ][0] );
 		
-		my $copy = $winnerline;
-		$copy =~ s/$mypath\/$file//;
-		my @taken = Sim::OPT::extractcase("$copy", \%mids); #say TOFILE "TAKEOPTIMA--->taken: " . dump(@taken);
-		my $newtarget = $taken[0]; #say TOFILE "TAKEOPTIMA\$newtarget--->: $newtarget";
-		$newtarget =~ s/$mypath\///;
-		my %newcarrier = %{$taken[1]}; #say TOFILE "TAKEOPTIMA\%newcarrier--->" . dump(%newcarrier);
-		say TOFILE "TAKEOPTIMA BEFORE->\@miditers: " . dump(@miditers);
-		%{ $miditers[$countcase] } = %newcarrier; #say TOFILE "TAKEOPTIMA AFTER->\@miditers: " . dump(@miditers);
+		if ( not ( $sourcesweeps[ $countcase ][ $countblock ][0] eq "p" ) )
+		{	say $tee "SETTING UP THINGS FOR GAUSS-SEIDEL - SEQUENTIAL - METHOD";
+			my ( @values, @keys );
+			foreach my $values_ref ( @backvalues )
+			{
+				my $key = $values_ref->[0];
+				my $value = $values_ref->[1];
+				push( @keys, $key );
+				push( @values, $value );
+			}
+			my $optimal = min( @values );
+			say $tee "OBTAINED--->\@keys " . dump( @keys );
+			say $tee "OBTAINED--->\@values " . dump( @values );
+			my $count = 0;
+			my ( $truewinnerline );
+			foreach my $value ( @values )
+			{
+				if ( $value == $optimal )
+				{
+					$truewinnerline = $keys[$count];
+					$count++;
+				}
+			}
+			say $tee "WAS--->\$winnerline " . dump( $winnerline );
+			say $tee "OBTAINED--->\$truewinnerline " . dump( $truewinnerline );
+			$copy = $truewinnerline;
+			$copy =~ s/$mypath\/$file//;
+			@taken = Sim::OPT::extractcase( "$copy", \%mids ); say $tee "TAKEOPTIMA>taken: " . dump(@taken);
+			$newtarget = $taken[0]; say $tee "TAKEOPTIMA\$newtarget>: $newtarget";
+			$newtarget =~ s/$mypath\///;
+			%newcarrier = %{ $taken[1] }; say $tee "TAKEOPTIMA\%newcarrier>" . dump( %newcarrier );
+			say $tee "TAKEOPTIMA BEFORE->\@miditers: " . dump(@miditers);
+			%{ $miditers[$countcase] } = %newcarrier; #say $tee "TAKEOPTIMA AFTER->\@miditers: " . dump(@miditers);
+			@backvalues = ( ); #EMPTY THE CONTAINER
+		}
+		else
+		{	say $tee "SETTING UP THINGS FOR JACOBI - PARALLEL - METHOD";
+			$copy = $winnerline;
+			$copy =~ s/$mypath\/$file//;
+			@taken = Sim::OPT::extractcase( "$copy", \%mids ); say $tee "TAKEOPTIMA--->taken: " . dump(@taken);
+			$newtarget = $taken[0]; say $tee "TAKEOPTIMA\$newtarget--->: $newtarget";
+			$newtarget =~ s/$mypath\///
+		}
 		
+		say $tee "TAKEOPTIMA AFTER->\@miditers: " . dump(@miditers);
 		#say "2\$countcase : " . dump($countcase);
 		#say "2\@rootnames : " . dump(@rootnames);
 		#say "2\$countblock : " . dump($countblock);
@@ -584,12 +632,12 @@ sub descend
 			my @morphcases = grep -d, <$mypath/$file_*>;
 			say $tee "#Optimal option for case  $countcaseplus: $newtarget";
 			#my $instnum = Sim::OPT::countarray( @{ $morphstruct[$countcase] } );
-			say $tee "#Gross number of instances: $instnum." ;
-			my $netinstnum = scalar(@morphcases);
+			#say $tee "#Gross number of instances: $instnum." ;
+			my $netinstnum = scalar( @morphcases );
 			say $tee "#Net number of instances: $netinstnum." ;
 			open( RESPONSE , ">$mypath/response.txt" );
 			say RESPONSE "#Optimal option for case  $countcaseplus: $newtarget";
-			say RESPONSE "#Gross number of instances: $instnum." ;
+			#say RESPONSE "#Gross number of instances: $instnum." ;
 			say RESPONSE "#Net number of instances: $netinstnum." ;
 				
 			$countblock = 0;
@@ -601,11 +649,13 @@ sub descend
 		}
 		else
 		{
-			push ( @{ $winneritems[$countcase][$countblock] }, $newtarget); say TOFILE "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
-			"#Leaving case " . ($countcase + 1) . ", block " . ($countblock + 1) . " and descending!\ ";
+			push ( @{ $winneritems[$countcase][$countblock] }, $newtarget); say $tee "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
+			say $tee "#Leaving case " . ($countcase + 1) . ", block " . ($countblock + 1) . " and descending!\ ";
 			Sim::OPT::callcase( { countcase => $countcase, countblock => $countblock, 
 			miditers => \@miditers,  winneritems => \@winneritems, 
-			dirfiles => \%dirfiles, uplift => \@uplift } );
+			dirfiles => \%dirfiles, uplift => \@uplift,
+			backvalues => \@backvalues,
+			sweeps => \@sweeps, sourcesweeps => \@sourcesweeps } );
 		}
 	}
 	takeoptima( $sortmixed, \@uplift );
@@ -628,7 +678,7 @@ Sim::OPT::Descend.
 
 =head1 DESCRIPTION
 
-Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent. It closes the circularly recursive loop formed by Sim::OPT -> Sim::OPT::Morph -> Sim::OPT::Sim -> Sim::OPT::Report::retrieve -> Sim::OPT::Report::report -> Sim::OPT::Descent, which repeats at every block search cycle.
+Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent, or parallel blocks search, or free mixes of the two. It closes the circularly recursive loop formed by Sim::OPT -> Sim::OPT::Morph -> Sim::OPT::Sim -> Sim::OPT::Report::retrieve -> Sim::OPT::Report::report -> Sim::OPT::Descent, which repeats at every block search cycle.
 
 The objective function for rating the performances of the candidate solutions can be obtained by the weighting of objective functions (performance indicators) performed by the Sim::OPT::Report module, which follows user-specified criteria.
 
@@ -638,7 +688,7 @@ The objective function for rating the performances of the candidate solutions ca
 
 =head1 SEE ALSO
 
-An example of configuration file for Sim::OPT::Descend is is packed in "optw.tar.gz" file in "examples" directory in this distribution. But mostly, reference to the source code should be made.
+An example of configuration file for Sim::OPT::Descend ("trap.pl", featuring a mix of sequential and parallel overlapping block search) is is packed in "optw.tar.gz" file in "examples" directory in this distribution. But mostly, reference to the source code should be made.
 
 =head1 AUTHOR
 
