@@ -37,7 +37,7 @@ use warnings::unused;
 
 our @EXPORT = qw( retrieve report get_files );
 
-$VERSION = '0.51.09'; # our $VERSION = '';
+$VERSION = '0.51.20'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results.';
 
 #########################################################################################
@@ -51,12 +51,10 @@ sub retrieve
 	my %dat = %$swap;
 	my @instances = @{ $dat{instances} }; #say "scalar(\@instances): " . scalar(@instances);
 	my $countcase = $dat{countcase}; #say TOFILE "dump(\$countcase): " . dump($countcase); # IT WILL BE SHADOWED. CUT ZZZ
-	my $countblock = $dat{countblock}; #say TOFILE "dump(\$countblock): " . dump($countblock); # IT WILL BE SHADOWED. CUT ZZZ		
+	my $countblock = $dat{countblock}; #say TOFILE "dump(\$countblock): " . dump($countblock); # IT WILL BE SHADOWED. CUT ZZZ
 	my %dirfiles = %{ $dat{dirfiles} }; #say "dump(\%dirfiles): " . dump(%dirfiles); 
 		
 	$configfile = $main::configfile; #say "dump(\$configfile): " . dump($configfile);
-	@sweeps = @main::sweeps; #say TOFILE "dump(\@sweeps): " . dump(@sweeps);
-	@sourcesweeps = @main::sourcesweeps; #say "dump(\@sourcesweeps): " . dump(@sourcesweeps);
 	@varinumbers = @main::varinumbers; #say "dump(\@varinumbers): " . dump(@varinumbers);
 	@mediumiters = @main::mediumiters;
 	@rootnames = @main::rootnames; #say "dump(\@rootnames): " . dump(@rootnames);
@@ -160,13 +158,17 @@ sub retrieve
 		my %d = %{$instance};
 		my $countcase = $d{countcase}; #say TOFILE "dump(\$countcase): " . dump($countcase);
 		my $countblock = $d{countblock}; #say TOFILE "dump(\$countblock): " . dump($countblock);
-		my @miditers = @{ $d{miditers} }; #say $tee "dump(\@miditers): " . dump(@miditers);
-		my @winneritems = @{ $d{winneritems} }; #say TOFILE "dumpIN( \@winneritems) " . dump(@winneritems);
+		my @miditers = @{ $d{miditers} }; say $tee "dump(\@miditers): " . dump(@miditers);
+		my @winneritems = @{ $d{winneritems} }; say $tee  "dumpIN( \@winneritems) " . dump(@winneritems);
 		my $countvar = $d{countvar}; #say TOFILE "dump(\$countvar): " . dump($countvar);
 		my $countstep = $d{countstep}; #say TOFILE "dump(\$countstep): " . dump($countstep);						
 		my $to = $d{to}; #say TOFILE "dump(\$to): " . dump($to);
 		my $origin = $d{origin}; #say TOFILE "dump(\$origin): " . dump($origin);
 		my @uplift = @{ $d{uplift} }; #say TOFILE "dump(\@uplift): " . dump(@uplift);
+		my @backvalues = @{ $d{backvalues} }; say $tee "IN RETRIEVE \@backvalues " . dump(@backvalues);
+		my @sweeps = @{ $d{sweeps} }; say $tee "dump(\@sweeps): " . dump(@sweeps);
+		my @sourcesweeps = @{ $d{sourcesweeps} }; say $tee "dump(\@sourcesweeps): " . dump(@sourcesweeps);
+		
 		#eval($getparshere);
 		
 		my $skip = $vals{$countvar}{skip}; #say $tee "dumpinreport(\$skip): " . dump($skip);
@@ -856,7 +858,6 @@ sub report # This function retrieves the results of interest from the texts file
 	my %dirfiles = %{ $dat{dirfiles} }; #say "dump(\%dirfiles): " . dump(%dirfiles); 
 		
 	$configfile = $main::configfile; #say "dump(\$configfile): " . dump($configfile);
-	@sweeps = @main::sweeps; #say "dump(\@sweeps): " . dump(@sweeps);
 	@varinumbers = @main::varinumbers; #say "dump(\@varinumbers): " . dump(@varinumbers);
 	@mediumiters = @main::mediumiters;
 	@rootnames = @main::rootnames; #say "dump(\@rootnames): " . dump(@rootnames);
@@ -951,6 +952,9 @@ sub report # This function retrieves the results of interest from the texts file
 		my $from = Sim::OPT::getline($toitem); #say TOFILE "dumpIN(\$from): " . dump($from);
 		my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); #say TOFILE "dumpIN---(\%varnums): " . dump(%varnums); 
 		my %mids = Sim::OPT::getcase(\@miditers, $countcase); #say TOFILE "dumpIN---(\%mids): " . dump(%mids); 
+		my @backvalues = @{ $d{backvalues} }; say $tee "IN REPORT \@backvalues " . dump(@backvalues);
+		my @sweeps = @{ $d{sweeps} }; say $tee "dump(\@sweeps): " . dump(@sweeps);
+		my @sourcesweeps = @{ $d{sourcesweeps} }; say $tee "dump(\@sourcesweeps): " . dump(@sourcesweeps);
 		
 		my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); #say TOFILE "dump(\$stepsvar): " . dump($stepsvar); 
 		my $varnumber = $countvar; #say TOFILE "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
@@ -1166,7 +1170,7 @@ sub report # This function retrieves the results of interest from the texts file
 			$counttool++;
 		}
 		#say $tee "\@mergestruct: " . dump(@mergestruct); 
-		say $tee "\@{ \$mergestruct[\$countcase][\$countblock][\$countinstance] } : " . dump(@{ $mergestruct[$countcase][$countblock][ $countinstance ] });
+		#say $tee "\@{ \$mergestruct[\$countcase][\$countblock][\$countinstance] } : " . dump(@{ $mergestruct[$countcase][$countblock][ $countinstance ] });
 		
 		unless ( $dowhat{inactivateret} eq "y" )
 		{
@@ -1205,8 +1209,8 @@ sub report # This function retrieves the results of interest from the texts file
 	
 	close REPFILE;
 		
-	#say TOFILE "HEREIS \@repcases " . dump(@repcases); say TOFILE "\@repstruct " . dump(@repstruct); say TOFILE "\@mergestruct " . dump(@mergestruct);
-	#say TOFILE "\@mergecases " . dump(@mergecases); say TOFILE "\$repfile: " . dump($repfile);
+	say $tee "HEREIS \@repcases " . dump(@repcases); say $tee "\@repstruct " . dump(@repstruct); #say $tee "\@mergestruct " . dump(@mergestruct);
+	#say TOFILE "\@mergecases " . dump(@mergecases);
 	close TOFILE;
 	close OUTFILE;
 	return ( \@repcases, \@repstruct, \@mergestruct, \@mergecases, $repfile ); 
