@@ -42,7 +42,7 @@ use warnings::unused;
 
 our @EXPORT = qw( sim ); # our @EXPORT = qw( );
 
-$VERSION = '0.50.01'; # our $VERSION = '';
+$VERSION = '0.50.02'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Sim is the module used by Sim::OPT to launch simulations once the models have been built.'; 
 
 #########################################################################################
@@ -63,12 +63,10 @@ sub sim    # This function launch the simulations in ESP-r
 	my %dat = %$swap;
 	my @instances = @{ $dat{instances} }; #say "scalar(\@instances): " . scalar(@instances);
 	my $countcase = $dat{countcase}; #say "dump(\$countcase): " . dump($countcase); # IT WILL BE SHADOWED. CUT ZZZ
-	my $countblock = $dat{countblock}; #say "dump(\$countblock): " . dump($countblock); # IT WILL BE SHADOWED. CUT ZZZ		
+	my $countblock = $dat{countblock}; #say "dump(\$countblock): " . dump($countblock); # IT WILL BE SHADOWED. CUT ZZZ			
 	my %dirfiles = %{ $dat{dirfiles} }; #say "dump(\%dirfiles): " . dump(%dirfiles); 
 		
 	$configfile = $main::configfile; #say "dump(\$configfile): " . dump($configfile);
-	@sweeps = @main::sweeps; #say "dump(\@sweeps): " . dump(@sweeps);
-	@sourcesweeps = @main::sourcesweeps; #say "dump(\@sourcesweeps): " . dump(@sourcesweeps);
 	@varinumbers = @main::varinumbers; #say "dump(\@varinumbers): " . dump(@varinumbers);
 	@mediumiters = @main::mediumiters;
 	@rootnames = @main::rootnames; #say "dump(\@rootnames): " . dump(@rootnames);
@@ -159,6 +157,9 @@ sub sim    # This function launch the simulations in ESP-r
 		my $to = $d{to}; #say TOFILE "dump(\$to): " . dump($to);
 		my $origin = $d{origin}; #say TOFILE "dump(\$origin): " . dump($origin);
 		my @uplift = @{ $d{uplift} }; #say TOFILE "dump(\@uplift): " . dump(@uplift);
+		my @backvalues = @{ $d{backvalues} }; #say $tee "IN SIM \@backvalues " . dump(@backvalues);
+		my @sweeps = @{ $d{sweeps} }; #say $tee "dump(\@sweeps): " . dump(@sweeps);
+		my @sourcesweeps = @{ $d{sourcesweeps} }; #say $tee "dump(\@sourcesweeps): " . dump(@sourcesweeps);
 		#eval($getparshere);
 		
 		my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOFILE "dump(\$rootname): " . dump($rootname);
